/* Copyright (C) 2011, 2012, 2013 by Bundesanstalt für Gewässerkunde
 * Software engineering by Intevation GmbH
 *
 * This file is Free Software under the GNU AGPL (>=v3)
 * and comes with ABSOLUTELY NO WARRANTY! Check out the
 * documentation coming with Dive4Elements River for details.
 */

package org.dive4elements.river.backend;

import org.dive4elements.artifacts.common.utils.Config;

import org.dive4elements.river.seddb.model.Bezugspegel;
import org.dive4elements.river.seddb.model.Bezugspegelgew;
import org.dive4elements.river.seddb.model.BezugspegelgewId;
import org.dive4elements.river.seddb.model.Bild;
import org.dive4elements.river.seddb.model.Gewaesser;
import org.dive4elements.river.seddb.model.Gfaenger;
import org.dive4elements.river.seddb.model.Glotlinks;
import org.dive4elements.river.seddb.model.GlotlinksId;
import org.dive4elements.river.seddb.model.Glotrechte;
import org.dive4elements.river.seddb.model.Gprobe;
import org.dive4elements.river.seddb.model.GprobeId;
import org.dive4elements.river.seddb.model.Gsiebsatz;
import org.dive4elements.river.seddb.model.Gsiebung;
import org.dive4elements.river.seddb.model.Gsiebungsieb;
import org.dive4elements.river.seddb.model.GsiebungsiebId;
import org.dive4elements.river.seddb.model.Hpeilpunkt;
import org.dive4elements.river.seddb.model.HpeilpunktId;
import org.dive4elements.river.seddb.model.Hpeilung;
import org.dive4elements.river.seddb.model.Messung;
import org.dive4elements.river.seddb.model.Messunglotcount;
import org.dive4elements.river.seddb.model.MessunglotcountId;
import org.dive4elements.river.seddb.model.Messungsta;
import org.dive4elements.river.seddb.model.MessungstaId;
import org.dive4elements.river.seddb.model.Messunguferbezug;
import org.dive4elements.river.seddb.model.MessunguferbezugId;
import org.dive4elements.river.seddb.model.Mpeilpunkt;
import org.dive4elements.river.seddb.model.MpeilpunktId;
import org.dive4elements.river.seddb.model.Mpeilung;
import org.dive4elements.river.seddb.model.Probebild;
import org.dive4elements.river.seddb.model.Siebanalyse;
import org.dive4elements.river.seddb.model.Slotlinks;
import org.dive4elements.river.seddb.model.SlotlinksId;
import org.dive4elements.river.seddb.model.Slotrechte;
import org.dive4elements.river.seddb.model.Sohlprobe;
import org.dive4elements.river.seddb.model.Sohltest;
import org.dive4elements.river.seddb.model.Sprobe;
import org.dive4elements.river.seddb.model.SprobeId;
import org.dive4elements.river.seddb.model.Ssiebung;
import org.dive4elements.river.seddb.model.Ssiebungsieb;
import org.dive4elements.river.seddb.model.SsiebungsiebId;
import org.dive4elements.river.seddb.model.Station;
import org.dive4elements.river.seddb.model.Stationgew;
import org.dive4elements.river.seddb.model.StationgewId;
import org.dive4elements.river.seddb.model.TmpGloChanged;
import org.dive4elements.river.seddb.model.TmpMesAchanged;
import org.dive4elements.river.seddb.model.TmpMesGchanged;
import org.dive4elements.river.seddb.model.TmpMesQchanged;
import org.dive4elements.river.seddb.model.TmpMesSchanged;
import org.dive4elements.river.seddb.model.Zzarchiv;
import org.dive4elements.river.seddb.model.Zzprobenahmeart;
import org.dive4elements.river.seddb.model.Zzsondierungart;
import org.dive4elements.river.seddb.model.Zzthema;

public class SedDBCredentials
extends      Credentials
{
    public static final String XPATH_USER =
        "/artifact-database/seddb-database/user/text()";

    public static final String XPATH_PASSWORD =
        "/artifact-database/seddb-database/password/text()";

    public static final String XPATH_DIALECT =
        "/artifact-database/seddb-database/dialect/text()";

    public static final String XPATH_DRIVER =
        "/artifact-database/seddb-database/driver/text()";

    public static final String XPATH_URL =
        "/artifact-database/seddb-database/url/text()";

    public static final String XPATH_CONNECTION_INIT_SQLS =
        "/artifact-database/seddb-database/connection-init-sqls/text()";

    public static final String DEFAULT_USER =
        System.getProperty("flys.seddb.user", "seddb");

    public static final String DEFAULT_PASSWORD =
        System.getProperty("flys.seddb.password", "seddb");

    public static final String DEFAULT_DIALECT =
        System.getProperty(
            "flys.seddb.dialect",
            "org.hibernate.dialect.PostgreSQLDialect");

    public static final String DEFAULT_DRIVER =
        System.getProperty(
            "flys.seddb.driver",
            "org.postgresql.Driver");

    public static final String DEFAULT_URL =
        System.getProperty(
            "flys.seddb.url",
            "jdbc:postgresql://localhost:5432/seddb");

    public static final String DEFAULT_CONNECTION_INIT_SQLS =
        System.getProperty(
            "flys.seddb.connection.init.sqls");

    public static final Class [] CLASSES = {
        BezugspegelgewId.class,
        Bezugspegelgew.class,
        Bezugspegel.class,
        Bild.class,
        Gewaesser.class,
        Gfaenger.class,
        GlotlinksId.class,
        Glotlinks.class,
        Glotrechte.class,
        GprobeId.class,
        Gprobe.class,
        Gsiebsatz.class,
        Gsiebung.class,
        GsiebungsiebId.class,
        Gsiebungsieb.class,
        HpeilpunktId.class,
        Hpeilpunkt.class,
        Hpeilung.class,
        Messung.class,
        MessunglotcountId.class,
        Messunglotcount.class,
        MessungstaId.class,
        Messungsta.class,
        MessunguferbezugId.class,
        Messunguferbezug.class,
        MpeilpunktId.class,
        Mpeilpunkt.class,
        Mpeilung.class,
        Probebild.class,
        Siebanalyse.class,
        SlotlinksId.class,
        Slotlinks.class,
        Slotrechte.class,
        Sohlprobe.class,
        Sohltest.class,
        SprobeId.class,
        Sprobe.class,
        Ssiebung.class,
        SsiebungsiebId.class,
        Ssiebungsieb.class,
        StationgewId.class,
        Stationgew.class,
        Station.class,
        TmpGloChanged.class,
        TmpMesAchanged.class,
        TmpMesGchanged.class,
        TmpMesQchanged.class,
        TmpMesSchanged.class,
        Zzarchiv.class,
        Zzprobenahmeart.class,
        Zzsondierungart.class,
        Zzthema.class
    };

    private static Credentials instance;

    public SedDBCredentials() {
    }

    public SedDBCredentials(
        String user,
        String password,
        String dialect,
        String driver,
        String url,
        String connectionInitSqls
    ) {
        super(
            user, password, dialect, driver, url, connectionInitSqls, CLASSES);
    }

    public static synchronized Credentials getInstance() {
        if (instance == null) {
            String user =
                Config.getStringXPath(XPATH_USER, DEFAULT_USER);
            String password =
                Config.getStringXPath(XPATH_PASSWORD, DEFAULT_PASSWORD);
            String dialect =
                Config.getStringXPath(XPATH_DIALECT, DEFAULT_DIALECT);
            String driver =
                Config.getStringXPath(XPATH_DRIVER, DEFAULT_DRIVER);
            String url =
                Config.getStringXPath(XPATH_URL, DEFAULT_URL);
            String connectionInitSqls =
                Config.getStringXPath(
                    XPATH_CONNECTION_INIT_SQLS,
                    DEFAULT_CONNECTION_INIT_SQLS);

            instance = new SedDBCredentials(
                user, password, dialect, driver, url, connectionInitSqls);
        }
        return instance;
    }

    public static Credentials getDefault() {
        return new SedDBCredentials(
            DEFAULT_USER,
            DEFAULT_PASSWORD,
            DEFAULT_DIALECT,
            DEFAULT_DRIVER,
            DEFAULT_URL,
            DEFAULT_CONNECTION_INIT_SQLS);
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf8 :
